using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Runtime.InteropServices;   // WritePrivateProfileString & GetPrivateProfileString use this

namespace CSharpDialogTest
{
    public partial class Form1 : Form
    {
        // WritePrivateProfileString & GetPrivateProfileString are used to save settings from a dialog box (uses System.Runtime.InteropServices):
        [DllImport("kernel32")]
        private static extern long WritePrivateProfileString(string section, string key, string val, string filePath);
        [DllImport("kernel32")]
        private static extern int GetPrivateProfileString(string section, string key, string def, StringBuilder retVal, int size, string filePath);

        static int counter = 0;     // a global variable to keep track of how many times the plugin is used by the config.
        static string email = "";   // a global test variable 
        static Form1 dialog = new Form1();  // the configure dialog 

        //Process.Start("Notepad.exe");    

        //======================================================================
        //== DLLTYPE ===========================================================
        //======================================================================
        public static int dlltype()
        {
            return 1;  // 1=Source; 2=Visual; 3=Source+Visual; 4=Input; 5=Input+Source; 6=Input+Visual; 7=Input+Source+Visual
        }

        //======================================================================
        //== DLLSTARTUP ========================================================
        //======================================================================
        public static int dllstartup(uint SammysHandle, int dlltype)
        {
            counter++;  // increment the counter each time the plugin is started by Samurize
            // MessageBox.Show(counter.ToString());  // .ToString() converts a number into a string
            // int.Parse(tempstr));                  // int.Parse() converts a string into a number
            return counter;   // return a unique number (this is useful for storing data for different instances)
        }

        //======================================================================
        //== DLLSHUTDOWN =======================================================
        //======================================================================
        public static int dllshutdown(int id)
        {
            //System.GC.Collect();    // <-- this probably isn't needed, but trying to plug mem leak
            //System.Environment.WorkingSet / (1024 * 1024);   // MB memory in use
            return 0;
        }

        //======================================================================
        //== GETINFO ===========================================================
        //======================================================================
        public static string getinfo(int id)
        {
            string result = "";
            switch (id)
            {
                case 0:
                    result = "C# example plugin";
                    break;
                case 1:
                    result = "uziq";
                    break;
                case 2:
                    result = "1.0";
                    break;
                case 3:
                    result = "November 19 2005";
                    break;
                case 4:
                    result = "November 28 2005";
                    break;
                case 5:
                    result = "http://www.geocities.com/samurize@swbell.net/samurize.html";
                    break;
                case 6:
                    result = "uziq@hotmail.com";
                    break;
                default:
                    break;
            }
            return result;
        }

        //======================================================================
        //== INIT (SOURCE PLUGINS) =============================================
        //======================================================================
        public static string init()
        {
            string func = "HelloWorld";
            return func;
        }

        //======================================================================
        //== GETPARAM (SOURCE PLUGINS) =========================================
        //======================================================================
        public static string getparam(string func)
        {
            string paramlist = "";
            if (func == "HelloWorld")
                paramlist = "Enter your first name|Enter your last name|";
            return paramlist;
        }

        //======================================================================
        //== CONFIGURE (SOURCE PLUGINS - GLOBAL) ===============================
        //======================================================================
        public static int configure()   // global configure settings
        {
            return 0;
        }

        //======================================================================
        //== SOURCE_CONFIGURE (SOURCE PLUGINS - PER METER) =====================
        //======================================================================
        public static int source_configure(int id, string func)    // per meter configure settings
        {
            if (func == "HelloWorld")
            {
                if (dialog.Visible)  // if the dialog is already showing..
                    dialog.Focus();  // re-focus
                else
                    dialog.Show();   // show (only happens the very first time)
            }
            return 0;
        }

        //======================================================================
        //== SRC_LOAD_SETTINGS (SOURCE PLUGINS) ================================
        //======================================================================
        public static int src_load_settings(int id, string ini, string section)
        {
            StringBuilder temp = new StringBuilder(255);
            GetPrivateProfileString(section, "email", "", temp, 255, ini);
            email = temp.ToString();
            // MessageBox.Show("src_load_settings" + "\r\n" + "email=" + temp);
            return 0;
        }

        //======================================================================
        //== SRC_SAVE_SETTINGS (SOURCE PLUGINS) ================================
        //======================================================================
        public static int src_save_settings(int id, string ini, string section)
        {
            WritePrivateProfileString(section, "email", email, ini);
            return 0;
        }

        //======================================================================
        //== HELLOWORLD ========================================================
        //======================================================================
        public static string HelloWorld(int id, string param1, string param2)
        {
            string result = "";
            if (param1 == "")
                result = "Hello!";
            else
                if (param2 == "")
                    result = "Hello " + param1 + "!";
                else
                    result = "Hello " + param1 + " " + param2 + "!";
            //MessageBox.Show(email);
            if (email.ToString() != "")
                result = result + "\r\n" + "email: " + email;
            else
                result = result + "\r\n" + "Click configure to enter your email address.";
            return result;
        }

        //======================================================================
        //== REPAINT (VISUAL PLUGINS) ==========================================
        //======================================================================
        public static int repaint(int hdc, int id, string value, int x, int y)
        {
            //this section is not completed yet!
            return 0;
        }


        //======================================================================
        //======================================================================
        //======================================================================
        // retrieve a webpage:
        //using System.Net; 
        //using System.IO; 
        //HttpWebRequest webReq = (HttpWebRequest)WebRequest.Create(txtfileUrl); 
        //HttpWebResponse webRes = (httpWebResponse)webReq.GetResponse(); 
        //Stream fileStream = webRes.GetResponseStream(); 
        //StreamReader fileReader = new StreamReader(fileStream, Encoding.UTF8); 
        //string fileContents = fileReader.ReadToEnd(); 



        //======================================================================
        //======================================================================
        //== DIALOG STUFF ======================================================
        //======================================================================
        //======================================================================
        
        public Form1()
        {
            InitializeComponent();
        }

        private void ButtonCancel_Click(object sender, EventArgs e)
        {
            dialog.Hide();
        }

        private void ButtonOK_Click(object sender, EventArgs e)
        {
            // get the email variable:
            email = emailtextbox.Text;
            dialog.Hide();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // put the email variable inside the textbox:
            emailtextbox.Text = email;
        }

    }
}